pwa_install_plus library
Classes
Enums
Functions
-
appInstalled(
) → void -
appLaunchedAsPWA(
) → void -
appLaunchedAsTWA(
) → void -
appLaunchedInBrowser(
) → void -
getLaunchMode(
) → void - Fetch the launch mode of the app from JavaScript The launch mode is determined by checking the display-mode media query value https://web.dev/customize-install/#track-how-the-pwa-was-launched
-
hasPrompt(
) → void -
promptInstall(
) → void - JavaScript functions that are called from Dart Show the PWA install prompt if it exists
-
setHasPrompt(
) → void -
setLaunchModeBrowser(
) → void -
setLaunchModePWA(
) → void -
setLaunchModeTWA(
) → void